#!/usr/bin/env python3
"""
Setup para instalar Bambu Lab Library
====================================
"""

from setuptools import setup, find_packages

# Leer README
try:
    with open("README.md", "r", encoding="utf-8") as fh:
        long_description = fh.read()
except FileNotFoundError:
    long_description = "Librería completa para control de impresoras Bambu Lab"

setup(
    name="bambuluc",
    version="1.0.3",
    author="Angel Luis Barbero Guerras",
    author_email="",  # Sin email público
    description="🖨️ Librería completa para control de impresoras Bambu Lab",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/AngelBarbero/bambuluc",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: Free for non-commercial use",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Hardware",
        "Topic :: Scientific/Engineering",
    ],
    python_requires=">=3.7",
    install_requires=[
        "paho-mqtt>=1.6.0",
        "requests>=2.25.0",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov",
            "black",
            "flake8",
            "mypy",
        ],
    },
    entry_points={
        "console_scripts": [
            "bambu-lab-example=bambu_lab_library:main",
        ],
    },
    project_urls={
        "Bug Reports": "https://github.com/AngelBarbero/bambuluc/issues",
        "Source": "https://github.com/AngelBarbero/bambuluc",
        "Documentation": "https://bambuluc.readthedocs.io/",
        "Funding": "https://github.com/sponsors/AngelBarbero",
    },
    keywords="bambu lab 3d printer mqtt ftp ssl control automation manufacturing",
    include_package_data=True,
    zip_safe=False,
    license="Custom Commercial License",
)
